szamlazz.py
----
A Python client for Szamlazz.hu :: Számla Agent

# Introduction
TBA

# Integration
TBA

# API
TBA

# Contribution
TBA

## New Release
Make sure you have the latest version of PyPA’s build installed:
```shell
python -m pip install --upgrade build
```

Run this command from the same directory where `pyproject.toml` is located:
```shell
python setup.py sdist bdist_wheel
```

# License
MIT
